@@ -9,74 +9,64 @@ from likes.api.pagination import get_pagination_class
 from likes.api.serializers import (
     LikeListSerializer,
     LikeToggleSerializer,
-    IsLikedSerializer
+    LikeContentTypeSerializer
 )
 from likes.models import Like
-from likes.services import user_likes_count
+from likes.selectors import get_liked_object_ids
+from likes.services import get_user_likes_count
 
 __all__ = (
-    'UserCountOfLikesAPIView',
-    'IsLikedAPIView',
-    'LikeListAPIView',
+    'LikedCountAPIView',
+    'LikedIDsAPIView',
     'LikeToggleView',
+    'LikeListAPIView',
 )
 
 
-class UserCountOfLikesAPIView(APIView):
+class LikedCountAPIView(APIView):
     """
     API View to return count of likes for authenticated user.
     """
     permission_classes = (AllowAny, )
 
     def get(self, request, *args, **kwargs):
+        serializer = LikeContentTypeSerializer(data=request.GET)
+        serializer.is_valid(raise_exception=True)
+
         return Response(
             data={
-                'count': user_likes_count(user=request.user)
+                'count': get_user_likes_count(
+                    user=request.user,
+                    content_type=(
+                        serializer.validated_data.get(
+                            'type'
+                        )
+                    )
+                )
             }
         )
 
 
-class IsLikedAPIView(GenericAPIView):
+class LikedIDsAPIView(APIView):
     """
     post:
-    API View to check is given elements are liked by authenticated user.\n
-    Possible payload:\n
-        {
-            "type": "app_label.model",  // object's content type's natural key joined string
-            "ids": [1,2,3]  // list of objects primary keys
-        }
+    API View to return liked objects ids for a given user.
     """
     permission_classes = (AllowAny, )
-    serializer_class = IsLikedSerializer
 
-    def post(self, request, *args, **kwargs):
-        serializer = self.get_serializer(data=request.data)
+    def get(self, request, *args, **kwargs):
+        serializer = LikeContentTypeSerializer(data=request.GET)
         serializer.is_valid(raise_exception=True)
-        return Response(serializer.validated_data)
 
-
-class LikeListAPIView(ListAPIView):
-    """
-    List API View to return all likes for authenticated user.
-    """
-    pagination_class = get_pagination_class()
-    permission_classes = (IsAuthenticated, )
-    serializer_class = LikeListSerializer
-    queryset = Like.objects.all()
-    filter_backends = (filters.SearchFilter, )
-    search_fields = (
-        'content_type__model',
-    )
-
-    def get_queryset(self):
-        return (
-            super()
-            .get_queryset()
-            .filter(
-                sender=self.request.user
-            )
-            .select_related('sender')
-            .distinct()
+        return Response(
+            data={
+                'ids': get_liked_object_ids(
+                    user=self.request.user,
+                    content_type=serializer.validated_data.get(
+                        'type'
+                    )
+                )
+            }
         )
 
 
@@ -104,3 +94,28 @@ class LikeToggleView(CreateAPIView):
             status=status.HTTP_201_CREATED,
             headers=self.get_success_headers(serializer.data)
         )
+
+
+class LikeListAPIView(ListAPIView):
+    """
+    List API View to return all likes for authenticated user.
+    """
+    pagination_class = get_pagination_class()
+    permission_classes = (IsAuthenticated, )
+    serializer_class = LikeListSerializer
+    queryset = Like.objects.all()
+    filter_backends = (filters.SearchFilter, )
+    search_fields = (
+        'content_type__model',
+    )
+
+    def get_queryset(self):
+        return (
+            super()
+            .get_queryset()
+            .filter(
+                sender=self.request.user
+            )
+            .select_related('sender')
+            .distinct()
+        )
