@@ -3,10 +3,10 @@ from django.template import Library
 
 from ..models import Like
 from likes.services import (
-    object_likes_count,
-    is_liked as is_liked_util,
-    get_who_liked
+    get_object_likes_count,
+    is_object_liked_by_user as is_liked_util
 )
+from ..selectors import get_users_who_liked_object, get_user_likes
 
 register = Library()
 
@@ -31,7 +31,7 @@ def likes_count(obj) -> int:
     or
         {{ obj|likes_count }}
     """
-    return object_likes_count(obj=obj)
+    return get_object_likes_count(obj=obj)
 
 
 @register.simple_tag
@@ -42,7 +42,7 @@ def who_liked(obj) -> QuerySet:
     Usage:
         {% who_liked object as fans %}
     """
-    return get_who_liked(obj=obj)
+    return get_users_who_liked_object(obj=obj)
 
 
 @register.simple_tag
@@ -53,7 +53,7 @@ def likes(user) -> QuerySet:
     Usage:
         {% likes request.user as var %}
     """
-    return Like.objects.filter(sender=user)
+    return get_user_likes(user=user)
 
 
 @register.simple_tag
